==> icons-vue-0.3.0.tgz: package/es/watson-health/iCA-2D/20.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../../chunk-75bb93d0.js';
import { getAttributes } from '@rocketsoftware/icon-helpers';

var virtual_WatsonHealthICa_2D20 = {
  name: 'WatsonHealthICa_2D20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '20',
      height: '20',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M2.001 21L2.001 30 11 30 11 28 4 28 4 21 2.001 21zM21.001 30L30 30 30 21 28.001 21 28.001 28 21.001 28 21.001 30zM22 24H10a2.0023 2.0023 0 0 1-2-2V10a2.002 2.002 0 0 1 2-2H22a2.0023 2.0023 0 0 1 2 2V22A2.0027 2.0027 0 0 1 22 24zM10 10V22H22.002L22 10zM30 11L30 2 21.001 2 21.001 4 28.001 4 28.001 11 30 11zM11 2L2.001 2 2.001 11 4 11 4 4 11 4 11 2z"
      }
    }), children]);
  }
};

export default virtual_WatsonHealthICa_2D20;

==> icons-vue-0.6.0.tgz: package/es/watson-health/iCA-2D/20.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../../_rollupPluginBabelHelpers-8169a350.js';
import { getAttributes } from '@rocketsoftware/icon-helpers';

var virtual_WatsonHealthICa_2D20 = {
  name: 'WatsonHealthICa_2D20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '20',
      height: '20',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('polygon', {
      attrs: {
        "points": "2.001 21 2.001 30 11 30 11 28 4 28 4 21 2.001 21"
      }
    }), createElement('polygon', {
      attrs: {
        "points": "21.001 30 30 30 30 21 28.001 21 28.001 28 21.001 28 21.001 30"
      }
    }), createElement('path', {
      attrs: {
        "d": "M22,24H10a2.0023,2.0023,0,0,1-2-2V10a2.002,2.002,0,0,1,2-2H22a2.0023,2.0023,0,0,1,2,2V22A2.0027,2.0027,0,0,1,22,24ZM10,10V22H22.002L22,10Z"
      }
    }), createElement('polygon', {
      attrs: {
        "points": "30 11 30 2 21.001 2 21.001 4 28.001 4 28.001 11 30 11"
      }
    }), createElement('polygon', {
      attrs: {
        "points": "11 2 2.001 2 2.001 11 4 11 4 4 11 4 11 2"
      }
    }), children]);
  }
};

export default virtual_WatsonHealthICa_2D20;
